
//  ################          An          ################
//  ################     include file     ################
//  ################          for         ################
//  ################    POV-Ray insect    ################
//  ################         traps        ################
//  ################          JDH         ################
//  ################           #          ################


//  Traps included so far: 
//  window_trap - an insecting pane window flight intercept trap
//  funnel_trap - a 12 funnel Lindgren funnel trap
//  purple_trap - a purple trap coated with Tangletrap
//  panel_trap - a Panel Trap for Bark Beetles (APT corp.)

//  To do:
//     1) Scaling - eventually I will scale these traps to 1 unit height
//     2) More traps - I'll get the panel trap finished.

//  Requires include files:  colors.inc, glass.inc .

//  These files are free to use and modify, just please acknowledge the source.
//  Send ideas for additional insect sampling objects to jdhollan[at]purdue.edu .
//     Cheers,  Jeffrey D. Holland, Purdue University


// ==========  Funnel Trap  ==========

#declare funnel_trap = union {

#declare funnel = union {
 difference {
   cone {<0, 0, 0>, 0.0 <0, 1.5, 0>, 1.0
      pigment {color Gray10}
      finish {phong 0.8}
        }  //  end outer cone
  union { 
   cone {<0, 0.02, 0>, 0.0, <0, 1.502, 0>, 1.0
      pigment {color Gray10}
      finish {phong 0.8}
         }  //  end subtract cone
   cylinder {<0, -0.1, 0>, <0, 1, 0>, 0.2
      pigment {color Black}
      finish {phong 0.8}
         }  //  end subtract hole
    }  //  end union subract cone + hole          
   }  // end cone difference 
   
 cylinder {<0.866, 0.5, -0.5>, <0.866, 1.501, -0.5>, 0.025
      pigment {color Black}
      finish {phong 0.6}
         }
 cylinder {<-0.866, 0.5, -0.5>, <-0.866, 1.501, -0.5>, 0.025        
      pigment {color Black}
      finish {phong 0.6}
         }
 cylinder {<0, 0.5, 1>, <0, 1.501, 1>, 0.025
      pigment {color Black}
      finish {phong 0.6}
         }
}  //  end funnel union         
                             
                 
#declare Count=1;
   #while (Count < 12)
      object {funnel rotate y*10*Count translate y*-0.8*Count}
      #declare Count = Count +1;
   #end

difference {             
cone {<0, 0, 0>, 0.0 <0, 1.5, 0>, 1.0
      pigment {color Gray10}
      finish {phong 0.8}
        }  //  end outer cone
  union { 
   cone {<0, 0.02, 0>, 0.0, <0, 1.502, 0>, 1.0
      pigment {color Gray10}
      finish {phong 0.8}
         }  //  end subtract cone
   cylinder {<0, -0.1, 0>, <0, 1, 0>, 0.2
      pigment {color Black}
      finish {phong 0.8}
         }  //  end subtract hole
    }  //  end union subract cone + hole          
translate y*-0.8*Count
   }  // end bottom cone no connectors


cylinder {<0, -8.3, 0>, <0, -9.9, 0>, 0.4
   pigment {color White}
   finish {phong 0.6}
   }  //  end collection cup
   
cylinder {<0, 0.65, 0>, <0, 0.72, 0>, 1.4
   pigment {color White}
   finish {phong 0.2}
   }  //  end rain cap
   
cylinder {<0, 0.65, 0>, <0, 3, 0>, 0.03
   pigment {color Gray50}
   finish {phong 1.0}
   }  //  end hanging wire
   
cone {<0, 0, 0>, 0.15, <0, -0.3, 0>, 0.11
   pigment {color Black}
   translate y*-9.8
   }  //  end bung
           
}  //  END FUNNEL_TRAP UNION


//  ==========  Window Trap ==========

#declare window_trap = union {
 box {<-0.25, 0, 0>, <0.25, 1, 0.01>
    texture {Glass2}
     }
 box {<0, 0, -0.25>, <0.01, 1, 0.25>
    texture {Glass2}
     }
    
 box {<-0.35, 1, -0.3>, <0.35, 1.002, 0.3>
    pigment {color White}
     }  //  end rain cap
     
 difference {
   cone {<0, -0.02, 0>, 0.24 <0, -0.5, 0>, 0
      pigment {color White}
      finish {phong 0.4}
        }  //  end outer cone
   union { 
     cone {<0, 0.0, 0>, 0.24, <0, -0.48, 0>, 0
      pigment {color White}
      finish {phong 0.4}
         }  //  end subtract cone    
     cylinder {<0, 0.01, 0>, <0, -1, 0>, 0.05
      pigment {color White}
      finish {phong 0.4}
         }  //  end subtract hole
    }  //  end union subract cone + hole          
   }  // end cone difference       
     
  cylinder {<0, -0.4, 0>, <0, -0.6, 0>, 0.07
    pigment {color White}
     }
     
  cylinder {<0, 0.99, 0>, <0, 2, 0>, 0.005
   pigment {color Gray50}
   finish {phong 1.0}
   }  //  end hanging wire   

}  //  END WINDOW_TRAP UNION 


//  ==========  Purple sticky trap  ==========

#declare binder_clip = prism {linear_spline 0.05, 0.08, 8
      <0.05, 0>, <0.068, 0.011>, <0.068, -0.011>, <0.05, 0>
      <0.0502, 0>, <0.0678, 0.0108>, <0.0678, -0.0108>, <0.0502, 0>
     };  //  end binder clip   

#declare purple_trap = union {
   box {<-0.0625, 0, 0.001>, <0.0625, 1.0, 0.0012>
      pigment {color Med_Purple}
      }
   box {<-0.0625, 0, -0.001>, <0.0625, 1.0, -0.0012>
      pigment {color Med_Purple}
      }
   cylinder {<0, 1.0, 0>, <0, 3, 0>, 0.003
      pigment {color Gray50}
      finish {metallic phong 1.0}
    }  //  end hanging wire
   box {<-0.0626, 0.04, -0.002>, <0.059, 0.96, 0.002>
      pigment {color rgbf<1, 1, 1, 0.7>}
      normal {bumps 0.04 scale 0.04}
      finish {phong 1}
     }  // end goop (Tangletrap) surface
   object {binder_clip}
   object {binder_clip translate y*0.42}
   object {binder_clip translate y*0.88}
  }  //  End purple_trap union.          
     
//  ===========  Panel Trap for Bark Beetles (APT Inc.)  ==========   

#declare panel = difference {
   box {<-0.5, 0, 0.01>, <0.5, 2, -0.01>
      pigment {color Gray10}
      finish {phong 1.0}
     }   
   box {<-0.08, 1.1, 0.011>, <0.08, 1.4, -0.11>
      pigment  {color Gray10}
     }  
   };  //  end panel.
   
#declare pyramidfunnel = union {
  intersection {
   plane { < 1, 0,  0>, 1  rotate <  0, 0,  40>}
   plane { <-1, 0,  0>, 1  rotate <  0, 0, -40>}
   plane { < 0, 0,  1>, 1  rotate <-40, 0,   0>}
   plane { < 0, 0, -1>, 1  rotate < 40, 0,   0>}
   plane { <0, -1, 0>, 0 }
   translate <0 ,-1, 0>
   bounded_by {box {<-1,0,-1>, <1,1,1>}}
   pigment {color Gray10}
   finish {phong 1.0}
   }  //  end 1st intersection
  intersection {
   plane { < 1, 0,  0>, 1  rotate <  0, 0,  40>}
   plane { <-1, 0,  0>, 1  rotate <  0, 0, -40>}
   plane { < 0, 0,  1>, 1  rotate <-40, 0,   0>}
   plane { < 0, 0, -1>, 1  rotate < 40, 0,   0>}
   plane { <0, -1, 0>, 0 }
   translate <0 ,-1, 0>
   bounded_by {box {<-1,0,-1>, <1,1,1>}}
   pigment {color Gray10}
   finish {phong 1.0}
   scale 0.99
   translate y*-0.01
   }  //  end 2nd intersection
   };  //  end union of two pieces             


#declare panel_trap = union{
        object {panel translate y*2}
        object {panel rotate y*90 translate y*2} 

        difference {
                object {pyramidfunnel 
                        scale 1.1
                        translate y*3.8
                        }
                box {<-0.5, 4.38, -0.5>, <0.5, 4.5, 0.5>}
                }  //  end hole for hanging wire.      
       };
              